@@ -1,4 +1,4 @@
-package Pcore::Chrome v0.13.0;
+package Pcore::Chrome v0.14.0;
 
 use Pcore -dist, -class, -res, -const;
 use Pcore::Chrome::Tab;
@@ -11,9 +11,9 @@ has port          => 9222;
 has user_data_dir => sub { P->file1->tempdir };
 has useragent     => ();
 
-has _proc     => ();
-has _pac      => ();
-has _pac_func => ();
+has _proc       => ();
+has _pac_server => ();
+has _pac_func   => ();
 
 # https://chromedevtools.github.io/devtools-protocol/tot/
 # https://peter.sh/experiments/chromium-command-line-switches/
@@ -42,7 +42,7 @@ around new => sub ( $orig, $self, %args ) {
 
     $self->_build_pac_func( $args{proxy} );
 
-    $self->_run_pac;
+    $self->_run_pac_server;
 
     my $cmd = [
         qq["$args{bin}"],
@@ -135,14 +135,10 @@ sub new_tab ( $self, $url = undef ) {
     return $tab;
 }
 
-sub reload_pac ($self) {
-    my $tab = $self->new_tab('about:blank');
+sub set_pac_func ( $self, $js ) {
+    $self->{_pac_func} = $js;
 
-    my $res = $tab->navigate_to('chrome://net-internals/#proxy');
-
-    $tab->('Runtime.enable');
-
-    $res = $tab->( 'Runtime.evaluate', { expression => q[document.getElementById("proxy-view-reload-settings").click()] } );
+    $self->reload_pac;
 
     return;
 }
@@ -155,6 +151,18 @@ sub set_proxy ( $self, $proxy ) {
     return;
 }
 
+sub reload_pac ($self) {
+    my $tab = $self->new_tab('about:blank');
+
+    my $res = $tab->navigate_to('chrome://net-internals/#proxy');
+
+    $tab->('Runtime.enable');
+
+    $res = $tab->( 'Runtime.evaluate', { expression => q[document.getElementById("proxy-view-reload-settings").click()] } );
+
+    return;
+}
+
 sub _build_pac_func ( $self, $proxy ) {
     my $pac_proxy;
 
@@ -184,12 +192,12 @@ JS
     return;
 }
 
-sub _run_pac ($self) {
+sub _run_pac_server ($self) {
     require Pcore::HTTP::Server;
 
     weaken $self;
 
-    $self->{_pac} = Pcore::HTTP::Server->new(
+    $self->{_pac_server} = Pcore::HTTP::Server->new(
         listen     => '//127.0.0.1:9999',
         on_request => sub ($req) {
             return 200, [ 'Content-Type' => 'application/x-ns-proxy-autoconfig' ], $self->{_pac_func} || $EMPTY;
